% LaTeX Dokumentenklasse fr die LNI Reihe der GI
%
% (C) 2002 Robert Tolksdorf
% Im Fall von Fragen zu dieser Dokumentenklasse wenden Sie sich bitte
% an mail@robert-tolksdorf.de
%
%
\ProvidesClass{lni}[2004/13/07 v0.41, by Robert Tolksdorf, Berlin]

\newif\ifpdf\ifx\pdfoutput\undefined\pdffalse\else\pdfoutput=1\pdftrue\fi

% Vielen Dank an Matthias Rust (mrust@rostock.zgdv.de) fuer folgende
% Angepasst an CID
\DeclareOption{forInclusion}{%
  \setlength{\topmargin}{0mm}%
  \setlength{\headheight}{0mm}%
  \setlength{\headsep}{0mm}%
  \setlength{\hoffset}{-72pt}% 
  \setlength{\voffset}{-72pt}% 
  \setlength{\oddsidemargin}{19mm}%
  \setlength{\evensidemargin}{10mm}%
  \setlength{\paperheight}{220mm}%
  \setlength{\paperwidth}{155mm}
  \ifpdf%
    \setlength{\pdfpageheight}{220mm}%
    \setlength{\pdfpagewidth}{155mm}%
  \fi}

\newif\iflnienglish\lnienglishfalse
\DeclareOption{english}{\lnienglishtrue}

%% CE     (nderungen fr Kurzbeitrge)
\newif\ifCEkurz\CEkurzfalse
\DeclareOption{kurz}{\CEkurztrue}
%%%%%

\ProcessOptions

% 10 pt
\LoadClass[10pt,fleqn,a4paper]{article}
\RequirePackage[english,ngerman]{babel}
\iflnienglish\selectlanguage{english}\def\bbl@main@language{english}\fi
% Blocksatz durch LaTeX-Default
% Satzspiegel
\setlength{\textheight}{192mm}
\setlength{\textwidth}{126mm}

%%% CE Anpassung fuer identische Positionierung wie bei Word:
\setlength{\hoffset}{-2.3mm}
\setlength{\voffset}{8.6mm}
%%%%%%%

% Times als Grundschrift
\RequirePackage{times}
% Hyphenation
% Durch normale LaTeX-Parameter verhindert (\doublehyphendemerits)

% Title: Kopie aus article.cls mit anderem \thispagestyle
\renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    \thispagestyle{empty}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
\def\@maketitle{%
  \newpage
  \null
  %\vskip 2em%  %% CE: auskommentiert, da unnoetig
  \begin{center}%
  \vspace*{-0.5mm} %% CE: neu hier, da oben nutzlos
  \let \footnote \thanks
    {\fontsize{14}{16}\fontseries{b}\selectfont \@title \par}%
    \vskip 0.7em% %% CE: vorher 1.5em
    {\fontsize{10}{12}\selectfont
      \lineskip .5em%
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
    \vskip 14mm% %% CE: vorher 1\baselineskip
  \end{center}%
  \par
  }

% Abstract
\renewenvironment*{abstract}{%
 \renewcommand{\abstractname}{Abstract}
 \fontsize{9}{10}\selectfont
    \quotation\noindent{\bfseries \abstractname:} \parindent 0pt%
}{\endquotation}  

% berschriften
\renewcommand{\section}{\@startsection{section}{1}{\z@}%
  {2\baselineskip}{\baselineskip}{\fontsize{12}{14}\fontseries{b}\selectfont}}
\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}%
  {1.4\baselineskip}{.5\baselineskip}{\fontsize{10}{12}\fontseries{b}\selectfont}}
% weitere nicht durch Formatvorlage geklrt

% keine seitennummern
\pagestyle{empty}

% Bildunterschriften
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  {\fontsize{9}{10}\selectfont
%   \sbox\@tempboxa{#1: #2}%
%  \ifdim \wd\@tempboxa >\hsize
%    #1: #2\par
%  \else
%    \global \@minipagefalse
%    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
%  \fi%
  \begin{center}#1: #2\vspace*{-0.3cm}\end{center} %% CE: vorher war bei langen Unterschriften alles linksbuendig!
  }
  \vskip\belowcaptionskip}

% gleichungen mit richtiger einrckung
% fleqn-Option oben
\setlength{\mathindent}{4ex}

% listings mit richtiger einrckung
\RequirePackage{verbatim}
\def\verbatim@processline{\hskip4ex\the\verbatim@line\par}

% Fussnoten mit 5cm Linie und richtiger Gre
\renewcommand\footnoterule{%
%%%% Original:
%  \kern-3\p@
%  \hrule\@width5cm
%  \kern2.6\p@}
%%%% CE:
  \vfill
  \hrule\@width5.1cm
  \kern2mm
}
\renewcommand\@makefntext[1]{%
    \parindent 1em%
    \noindent
%    \hb@xt@1.8em{\hss\@makefnmark}{\fontsize{8}{9}\selectfont#1}}
    \hb@xt@5pt{\hss\@makefnmark}{\hspace*{2pt}\fontsize{8}{9}\selectfont#1}}  %% CE

% Gemutmate Absatzeinzge und Abstnde
\parindent0pt
\parskip 1ex

%%% CE: Vermeidung Schusterjungen/Hurenkinder
\clubpenalty10000
\widowpenalty10000
\displaywidowpenalty10000
%%%%

% bibliography
\iflanguage{english}{\bibliographystyle{lni}}{\bibliographystyle{lnig}}
\renewenvironment{thebibliography}[1]
     {\def\refname{Literaturverzeichnis}
      \ifCEkurz%
        \protect\par\vspace{6pt}\textbf{\large\refname}\\[-15pt]%
      \else
        \section*{\refname}%
      \fi  
      \bgroup\fontsize{9}{10}\selectfont
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            %% CE: verkleinerter Abstand
            \itemsep -4pt
            %%%%%%%
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty10000    %%% CE: original 4000
      \@clubpenalty \clubpenalty
      \widowpenalty10000%  %%% CE: original 4000
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist\egroup}
